@@ -39,6 +39,7 @@ func init() {
 	DownloadCmd.AddCommand(pccCmd)
 
 	pccCmd.Flags().BoolP("info", "i", false, "Show PCC Release info")
+	// TODO: write to '/var/root/Library/Application Support/com.apple.security-research.pccvre/' to create a PCC VM w/o needing to set the csrutil first
 	pccCmd.Flags().StringP("output", "o", "", "Output directory to save files to")
 	viper.BindPFlag("download.pcc.info", pccCmd.Flags().Lookup("info"))
 	viper.BindPFlag("download.pcc.output", pccCmd.Flags().Lookup("output"))
@@ -61,7 +62,7 @@ func init() {
 // pccCmd represents the pcc command
 var pccCmd = &cobra.Command{
 	Use:           "pcc",
-	Aliases:       []string{"p", "vre"},
+	Aliases:       []string{"p", "vre", "pccvre"},
 	Short:         "🚧 Download PCC VM files",
 	SilenceUsage:  false,
 	SilenceErrors: true,
@@ -98,7 +99,9 @@ var pccCmd = &cobra.Command{
 		if viper.GetBool("download.pcc.info") {
 			log.Infof("Found %d PCC Releases", len(releases))
 			for _, release := range releases {
+				fmt.Println(" ╭╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴")
 				fmt.Println(release)
+				fmt.Println(" ╰╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴╴")
 			}
 		} else {
 			var choices []string
