@@ -126,7 +126,7 @@ var mdevsCmd = &cobra.Command{
 			defer func() {
 				log.Debugf("Unmounting %s", dmgPath)
 				if err := utils.Retry(3, 2*time.Second, func() error {
-					return utils.Unmount(mountPoint, false)
+					return utils.Unmount(mountPoint, true)
 				}); err != nil {
 					log.Errorf("failed to unmount %s at %s: %v", dmgPath, mountPoint, err)
 				}
